@@ -10,6 +10,8 @@ from . import defaults
 from .config import Config
 from .version import VERSION
 from .visitors.plu001_visitor import PLU001Visitor
+from .visitors.plu002_visitor import PLU002Visitor
+from .visitors.plu003_visitor import PLU003Visitor
 
 
 class Plugin:
@@ -19,6 +21,8 @@ class Plugin:
     version = VERSION
     visitors = [
         PLU001Visitor,
+        PLU002Visitor,
+        PLU003Visitor,
     ]
 
     def __init__(self, tree: ast.AST, lines: list[str]):
@@ -44,7 +48,7 @@ class Plugin:
             visitor = cls(self._lines, Plugin.config)
             visitor.visit(self._tree)
             for p in visitor.problems:
-                yield p.line_number, p.col_offset, p.formatted_message, type(self)
+                yield p.line_number, p.col_offset, p.message_with_code, type(self)
 
     @staticmethod
     def add_options(option_manager: OptionManager) -> None:  # pragma: no cover
@@ -59,7 +63,30 @@ class Plugin:
             "(Default: %(default)s)",
         )
 
+        option_manager.add_option(
+            "--blanks-before-return",
+            type="int",
+            metavar="n",
+            default=defaults.BLANKS_BEFORE_RETURN,
+            parse_from_config=True,
+            help="Expected number of blank lines before return statement. "
+            "(Default: %(default)s)",
+        )
+
+        option_manager.add_option(
+            "--blanks-before-except",
+            type="int",
+            metavar="n",
+            default=defaults.BLANKS_BEFORE_EXCEPT,
+            parse_from_config=True,
+            help="Expected number of blank lines before except. (Default: %(default)s)",
+        )
+
     @classmethod
     def parse_options(cls, options: Namespace) -> None:  # pragma: no cover
         """Parse the custom configuration options given to flake8."""
-        cls.config = Config(options.blanks_before_imports)
+        cls.config = Config(
+            options.blanks_before_imports,
+            options.blanks_before_return,
+            options.blanks_before_except,
+        )
